#!/usr/bin/env ruby
# -*- encoding: utf-8 -*-

$:.unshift File.dirname(__FILE__)
require 'time'
require 'thor'
require 'utils'

SMALL_WIDTH = 160
SMALL_HEIGHT = 160
COLLAGE_WIDTH = 5
COLLAGE_HEIGHT = 2
NUM_KEYWORDS = 10 # Expected number of keywords

module Fccc
  class CLI < Thor
    desc "collage keyword1, keyword2, ..., keyword#{NUM_KEYWORDS}", "This will search a top-rated image for each keyword and create collage with them."
    option :output
    option :input
    def collage(*keywords)
      collage = Utils::Collage.new(SMALL_WIDTH, SMALL_HEIGHT, COLLAGE_WIDTH, COLLAGE_HEIGHT, NUM_KEYWORDS)
      if !options[:input].nil?
        # Get keywords from a file
        keywords = File.readlines(File.join(Dir.pwd, "#{options[:input]}")).map do |line|
          line.strip if line.strip != ""
        end
      end
      # Clean up keywords
      keywords = keywords.map do |kw|
        kw.gsub(/[,]/ ,"").strip
      end
      # Force resize keywords array.
      # If it has more than NUM_KEYWORDS elements, just ignore extra elements.
      # If it has less than NUM_KEYWORDS elements, fill the rest with nil.
      keywords = Array.new(NUM_KEYWORDS).zip(keywords).map(&:last)
      # Download images
      collage.download_images_by_keywords(keywords)
      # Create and save collage
      output = options[:output]
      if output.nil?
        # Default filename with timestamp
        output_file = File.join(Dir.pwd, "collage-#{Time.now.utc.iso8601.gsub(/[:]/ ,"-")}.jpg")
      else
        # User-supplied filename
        output_file = File.join(Dir.pwd, "#{output}.jpg")
        while File.exist?(output_file) do
          # Increment suffix if the file exists
          output_file = Utils.increment_filename(output_file)
        end
      end
      collage.create_collage(output_file)
    end
  end
end
